pilas.interpolaciones.Lineal

Package pilas :: Module interpolaciones :: Class Lineal |
[hide private]
[frames] | no frames]

# Class Lineal

source code

       object --+
                |
    Interpolacion --+
                    |
                   Lineal

Representa una interpolación lineal.

Instance Methods | [hide private]
__init__(self, values, duration, delay) Inicializa la interpolación. | source code
__neg__(self) Retorna la interpolación inversa a la original. | source code
apply(self, target, function) Aplica la interpolación a un actor usando un método. | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, values, duration, delay) (Constructor) | source code
Inicializa la interpolación. ``values`` tiene que ser una lista con todos los puntos por los que se quiere adoptar valores y ``duration`` es la cantidad de segundos que deben tomarse para realizar la interpolación. Overrides: object.__init__ (inherited documentation)

### apply(self, target, function) | source code
Aplica la interpolación a un actor usando un método. Esta funcionalidad se utiliza para que toda interpolación se pueda acoplar a un actor. La idea es contar con la interpolación, un actor y luego ponerla en funcionamiento:
       mi_interpolacion.apply(mono, set_rotation)
de esta forma los dos objetos están y seguirán estando desacoplados. Overrides: Interpolacion.apply (inherited documentation)